==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/KontoBankowe.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class KontoBankowe extends GenericDPSObject {
    /**
     * KONTO_BANKOWE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * KONTO_BANKOWE.IBAN
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String iban;

    /**
     * KONTO_BANKOWE.LICZNIK_UZYCIE
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer licznikUzycie;

    /**
     * KONTO_BANKOWE.LICZNIK_PRZYPISAN
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer licznikPrzypisan;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KONTO_BANKOWE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * KONTO_BANKOWE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return KONTO_BANKOWE.IBAN
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getIban() {
        return iban;
    }

    /**
     * KONTO_BANKOWE.IBAN
     *
     * @param iban
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setIban(String iban) {
        this.iban = iban == null ? null : iban.trim();
    }

    /**
     * @return KONTO_BANKOWE.LICZNIK_UZYCIE
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getLicznikUzycie() {
        return licznikUzycie;
    }

    /**
     * KONTO_BANKOWE.LICZNIK_UZYCIE
     *
     * @param licznikUzycie
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLicznikUzycie(Integer licznikUzycie) {
        this.licznikUzycie = licznikUzycie;
    }

    /**
     * @return KONTO_BANKOWE.LICZNIK_PRZYPISAN
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getLicznikPrzypisan() {
        return licznikPrzypisan;
    }

    /**
     * KONTO_BANKOWE.LICZNIK_PRZYPISAN
     *
     * @param licznikPrzypisan
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLicznikPrzypisan(Integer licznikPrzypisan) {
        this.licznikPrzypisan = licznikPrzypisan;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KontoBankowe other = (KontoBankowe) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getIban() == null ? other.getIban() == null : this.getIban().equals(other.getIban()))
            && (this.getLicznikUzycie() == null ? other.getLicznikUzycie() == null : this.getLicznikUzycie().equals(other.getLicznikUzycie()))
            && (this.getLicznikPrzypisan() == null ? other.getLicznikPrzypisan() == null : this.getLicznikPrzypisan().equals(other.getLicznikPrzypisan()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getIban() == null) ? 0 : getIban().hashCode());
        result = prime * result + ((getLicznikUzycie() == null) ? 0 : getLicznikUzycie().hashCode());
        result = prime * result + ((getLicznikPrzypisan() == null) ? 0 : getLicznikPrzypisan().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", iban=").append(iban);
        sb.append(", licznikUzycie=").append(licznikUzycie);
        sb.append(", licznikPrzypisan=").append(licznikPrzypisan);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/KontoBankowe.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class KontoBankowe extends GenericDPSObject {
    /**
     * KONTO_BANKOWE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * KONTO_BANKOWE.IBAN
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String iban;

    /**
     * KONTO_BANKOWE.LICZNIK_UZYCIE
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer licznikUzycie;

    /**
     * KONTO_BANKOWE.LICZNIK_PRZYPISAN
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer licznikPrzypisan;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KONTO_BANKOWE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * KONTO_BANKOWE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return KONTO_BANKOWE.IBAN
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getIban() {
        return iban;
    }

    /**
     * KONTO_BANKOWE.IBAN
     *
     * @param iban
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setIban(String iban) {
        this.iban = iban == null ? null : iban.trim();
    }

    /**
     * @return KONTO_BANKOWE.LICZNIK_UZYCIE
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getLicznikUzycie() {
        return licznikUzycie;
    }

    /**
     * KONTO_BANKOWE.LICZNIK_UZYCIE
     *
     * @param licznikUzycie
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLicznikUzycie(Integer licznikUzycie) {
        this.licznikUzycie = licznikUzycie;
    }

    /**
     * @return KONTO_BANKOWE.LICZNIK_PRZYPISAN
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getLicznikPrzypisan() {
        return licznikPrzypisan;
    }

    /**
     * KONTO_BANKOWE.LICZNIK_PRZYPISAN
     *
     * @param licznikPrzypisan
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLicznikPrzypisan(Integer licznikPrzypisan) {
        this.licznikPrzypisan = licznikPrzypisan;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KontoBankowe other = (KontoBankowe) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getIban() == null ? other.getIban() == null : this.getIban().equals(other.getIban()))
            && (this.getLicznikUzycie() == null ? other.getLicznikUzycie() == null : this.getLicznikUzycie().equals(other.getLicznikUzycie()))
            && (this.getLicznikPrzypisan() == null ? other.getLicznikPrzypisan() == null : this.getLicznikPrzypisan().equals(other.getLicznikPrzypisan()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getIban() == null) ? 0 : getIban().hashCode());
        result = prime * result + ((getLicznikUzycie() == null) ? 0 : getLicznikUzycie().hashCode());
        result = prime * result + ((getLicznikPrzypisan() == null) ? 0 : getLicznikPrzypisan().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", iban=").append(iban);
        sb.append(", licznikUzycie=").append(licznikUzycie);
        sb.append(", licznikPrzypisan=").append(licznikPrzypisan);
        sb.append("]");
        return sb.toString();
    }
}
